# DGLAB-python-driver

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pydglab) ![PyPI - Version](https://img.shields.io/pypi/v/pydglab) ![PyPI - License](https://img.shields.io/pypi/l/pydglab)

 PyDGLAB - A Third-party DGLAB Python Driver
 
 **注意：目前这仍然是一个未完成的模块，请在使用前自行斟酌。**
 
 **CAUTION: This module is still under development. Think before use.**

 Check demo.py for more info.

 目前仅支持郊狼2.0，3.0的支持将在之后更新。

 ### 接下来可能会实现的功能：

 - 让郊狼2.0实现与郊狼3.0相同的websocket远控